ClassDefinition class

Constructors

ClassDefinition(String _name, [bool _privateFields = false])

Properties

dependencies → List<Dependency>
no setter
fields → Map<String, TypeDefinition>
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
no setter
privateFields → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addField(String name, TypeDefinition typeDef) → dynamic
hasField(TypeDefinition otherField) → dynamic
isSubsetOf(ClassDefinition other) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override