TypeDefinition class

Constructors

TypeDefinition(String name, {String? subtype, bool isAmbiguous = false, Node? astNode})
TypeDefinition.fromDynamic(dynamic obj, Node? astNode)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isAmbiguous ↔ bool
getter/setter pair
isPrimitive → bool
no setter
isPrimitiveList → bool
no setter
name ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtype ↔ String?
getter/setter pair

Methods

jsonParseExpression(String key, bool privateField) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJsonExpression(String key, bool privateField) → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override